\name{plotRangeL}
\alias{plotRangeL}
\title{plotRangeL: Plot a haplotype cluster given samples, tagSNVs, and their physical positions}
\description{

  \code{plotRangeL}: \R implementation of \code{plotRangeL}.

  A haplotype cluster is plotted where samples to plot are provided together with tagSNVs and their
  physical positions. Also other annotations of tagSNVs (as belonging to another genome) can
  be visualized.


}
\usage{

plotRangeL(Lout,ibb,physPos=NULL,colRamp=12,val=c(0.0,2.0,1.0),chrom=1,count=0,labelsNA=NULL,prange=NULL,labelsNA1 = c("model L") )

}
\arguments{
  \item{Lout}{the alleles of the samples are provided; typically via a previous call
  of the \pkg{fabia} function \code{readSamplesSpfabia}.}
  \item{ibb}{tagSNVs given as numbers if all SNVs are enumerated.}
  \item{physPos}{physical position of tagSNVs in bp.}
  \item{colRamp}{passed to \code{snpPlot}: color representation.}
  \item{val}{vector of 3 components containing values for representation
    of reference allele, minor allele that is not tagSNV,
   minor allele that is tagSNV, respectively.}
  \item{chrom}{chromosome.}
  \item{count}{counter which is shown in the title if larger than 0 (for viewing a series of haplotype clusters).}
  \item{labelsNA}{labels for the individuals.}
  \item{prange}{vector of two integer values giving the begin and end of
   a subsegment of the segment for zooming in.}
  \item{labelsNA1}{labels for model L obtained by \pkg{fabia} but also other annotations
   given as a vector of strings.}


}
\details{

  A haplotype cluster is plotted showing reference alleles, minor alleles that are not tagSNVs,
  and minor alleles that are tagSNVs.
  Provided are samples to plot together with tagSNVs and their
  physical positions.
  Also other annotations of tagSNVs (as belonging to another genome) can
  be visualized.

  Implementation in \R.

}
\seealso{
\code{\link{hapFabia}},
\code{\link{vcftoFABIA}},
\code{\link{split_sparse_matrix}},
\code{\link{iterateSegments}},
\code{\link{getIBDs}},
\code{\link{extractIBD}},
\code{\link{compareIBDres}},
\code{\link{mergeIBDres}},
\code{\link{identifyDuplicates}},
\code{\link{ibd2excel}},
\code{\link{plotRangeL}},
\code{\link{plotOneIBD}},
\code{\link{plotIBDs}},
\code{\link{snpPlot}},
\code{\link{analyzeIBDs}},
\code{\link{simulateHaplotypes}},
\code{\link{simulateForFabia}},
\code{\link{sim}},
\code{\link{topLZ}},
\code{\link{histL}},
\code{\link{plotL}},
\code{\link{hapRes}},
\code{\link{res}},
\code{\link{simu}},
\code{\link{mergedIBD}}
}
\author{Sepp Hochreiter}
\examples{

library(fabia)
data(hapRes)
data(simu)
namesL <- simu[[1]]
haploN <- simu[[2]]
snps <- simu[[3]]
annot <- simu[[4]]
alleleIimp <- simu[[5]]
write.table(namesL,file="dataSim1fabia_samples.txt",quote = FALSE,row.names = FALSE,col.names = FALSE)
write(as.integer(haploN),file="dataSim1fabia_annot.txt",ncolumns=100)
write(as.integer(snps),file="dataSim1fabia_annot.txt",append=TRUE,ncolumns=100)
write.table(annot,file="dataSim1fabia_annot.txt", sep = " ", quote = FALSE,row.names = FALSE,col.names = FALSE,append=TRUE)
write(as.integer(haploN),file="dataSim1fabia_mat.txt",ncolumns=100)
write(as.integer(snps),file="dataSim1fabia_mat.txt",append=TRUE,ncolumns=100)

for (i in 1:haploN) {

  a1 <- which(alleleIimp[i,]>0.01)

  al <- length(a1)
  b1 <- alleleIimp[i,a1]

  a1 <- a1 - 1
  dim(a1) <- c(1,al)
  b1 <- format(as.double(b1),nsmall=1)
  dim(b1) <- c(1,al)

  write.table(al,file="dataSim1fabia_mat.txt", sep = " ", quote = FALSE,row.names = FALSE,col.names = FALSE,append=TRUE)
  write.table(a1,file="dataSim1fabia_mat.txt", sep = " ", quote = FALSE,row.names = FALSE,col.names = FALSE,append=TRUE)
  write.table(b1,file="dataSim1fabia_mat.txt", sep = " ", quote = FALSE,row.names = FALSE,col.names = FALSE,append=TRUE)

}



IBD <- hapRes$mergedIBD
samp <- IBD[[1]]$noSamples
ibb <- IBD[[1]]$noSnps
ibb <- as.integer(sort.int(as.integer(unique(ibb))))
snpPositions <- IBD[[1]]$snpPositions
labels_ALL <- IBD[[1]]$labelSamples
Lout <- readSamplesSpfabia(X="dataSim1fabia_mat",samples=samp,lowerB=0,upperB=1000.0)
ibbL <- list(ibb)
labelsK <- c("model L")
plotRangeL(Lout=Lout,ibb=ibbL,physPos=snpPositions,colRamp=12,val=c(0.0,2.0,1.0),chrom=1,count=0,labelsNA=labels_ALL,labelsNA1=labelsK)

unlink("dataSim1fabia_mat.txt")
unlink("dataSim1fabia_annot.txt")
unlink("dataSim1fabia_samples.txt")

}

\references{

S. Hochreiter et al.,
\sQuote{FABIA: Factor Analysis for Bicluster Acquisition},
Bioinformatics 26(12):1520-1527, 2010.

}
\keyword{hplot}
\concept{genetics,haplotype,identity by descent,bicluster,next generation sequencing,genotype,single nucleotide polymorphism,single nucleotide variation,rare variants,rare SNPs, rare SNVs,rare haplotype clusters,short haplotype clusters}
